#
# spec file for package pstoedit
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pstoedit
Version:        4.02
Release:        1.4
Summary:        PostScript and PDF Converter
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/PS
URL:            http://www.pstoedit.net/
Source:         https://sourceforge.net/projects/pstoedit/files/pstoedit/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  gd-devel
BuildRequires:  ghostscript-devel
BuildRequires:  libEMF-devel
BuildRequires:  libMagick++-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  libzip-devel
BuildRequires:  pkgconfig
BuildRequires:  plotutils-devel
Requires:       ghostscript

%description
pstoedit converts PostScript and PDF files to other vector graphic
formats so that they can be edited graphically.

pstoedit supports:

* Tgif .obj format (for tgif version >= 3)
* .fig format for xfig
* pdf - Adobe's Portable Document Format
* gnuplot format
* Flattened PostScript (with or without Bezier curves)
* DXF - CAD exchange format
* LWO - LightWave 3D
* RIB - RenderMan
* RPL - Real3D
* Java 1 or Java 2 applet
* Idraw format (in fact a special form of EPS that idraw can read)
* Tcl/Tk
* HPGL
* AI (Adobe Illustrator) (based on ps2ai.ps - not a real pstoedit driver - see notes below and manual)
* Windows Meta Files (WMF) (Windows only)
* Enhanced Windows Meta Files (EMF) (Windows, but also Linux/Unix if libemf is available)
* OS/2 meta files (OS/2 only)
* PIC format for troff/groff
* MetaPost format for usage with TeX/LaTeX
* LaTeX2e picture
* Kontour
* GNU Metafile (plotutils / libplot)
* Skencil ( http://www.skencil.org )
* Mathematica
* via ImageMagick to any format supported by ImageMagick
* SWF
* CNC G code
* VTK files for ParaView and similar visualization tools

%package devel
Summary:        PostScript and PDF converter (development files)
Group:          Productivity/Publishing/PS
Requires:       %{name} = %{version}
Requires:       ImageMagick-devel
Requires:       libMagick++-devel
Requires:       libpng-devel
Requires:       libzip-devel

%description devel
PostScript and PDF converter development headers and library files.

%prep
%autosetup -p1
for CRLFFILE in doc/readme.txt examples/figtext.ps ; do
	tr -d '\r' <$CRLFFILE >$CRLFFILE.lf
	touch -r $CRLFFILE $CRLFFILE.lf
	mv $CRLFFILE.lf $CRLFFILE
done

%build
# --without-swf: lacking libming package
%configure \
	--disable-static \
	--with-emf \
	--with-magick \
	--with-libplot \
	--with-pptx \
	--without-swf

%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# doc cleanup
rm -rf examples/Makefile*
rm -rf %{buildroot}/usr/share/doc/%{name}

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%{_bindir}/pstoedit
%{_libdir}/*.so.*
%dir %{_libdir}/pstoedit
%{_libdir}/pstoedit/*.so
%{_datadir}/%{name}
%{_mandir}/man?*/*.*
%defattr(644, -, -, 755)
%license copying
%doc examples doc/readme.txt
%doc doc/*.htm doc/%{name}.pdf

%files devel
%{_libdir}/*.so
%{_includedir}/pstoedit
%{_libdir}/pkgconfig/*.pc
%{_datadir}/aclocal/*.m4

%changelog
* Sun Dec  1 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to version 4.02:
  * Improve the build process to build also the GUI if QT is installed.
  * Include a .desktop and Icon file for better Linux integration.
  * Update the autoconf tools to enable the usage of homebrew.
  * Update reflecting changes in GhostScript 10.03 and 10.04 (disable
    some operators used by pstoedit).
  * Fix a few warnings issued by Coverity.
  * Improve code for g++ V14.
  * Implemented sourceforge feature request #4 (show -nc option in GUI).
* Wed Apr 10 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to version 4.01:
  * Add creation of startmenu and desktop shortcuts in Windows installer.
  * Include some minor header patches for support of autotrace.
  * Improvements to the pcb-rnd driver contributed by Erich Heinzle.
    Limit polygon exports to pcb-rnd subcircuits to only those paths which
    are not self intersecting.
  * Fixed a bug found on MacOS reported by Sean Molenaar.
  * Some minor improvements to the GUI.
  * Some minor code cleanups to reduce warnings from clang compiler.
  * Some code changes to address a warning from AddressSanitizer.
  * Enable installation with winget.
- Remove default attributes for doc files (issue was fixed upstream).
- Don't run autogen.sh
* Fri Jun 30 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to version 4.00:
  * Many changes in internal APIs for supporting a GUI.
  * First version of QT base GUI. Not yet part of standard build
    process. Sources are in QT/PstoeditQtGui directory. Just run
    "make GUI" in there to build the GUI.
  * Code cleanup.
  * Some fixes to pass newer Coverity checks. Src code has again 0
    Coverity defects.
  * Documentation update and cleanup.
  * Fix compilation problem with newer GNU libstdc++.
  * Use unversioned .so libs for the driver plugins. Contributed
    by the Suse team.
  * Remove the usage of __DATE__ in source code to allow "reproducible"
    builds. Contributed by the Suse team.
- Drop upstreamed patches:
  * pstoedit-include.patch
  * pstoedit-unversioned.patch
  * reproducible.patch
- Add default attributes for documentation files.
  Fixes doc files having executable flag.
* Wed Jun 15 2022 Stanislav Brabec <sbrabec@suse.com>
- Fix build with libstdc++ 12.1 (pstoedit-include.patch).
- Convert text files to UNIX style line ends.
- Do not use version numbers for modules that are loaded as *.so
  (pstoedit-unversioned.patch).
* Thu Feb  3 2022 Stanislav Brabec <sbrabec@suse.com>
- Update to version 3.78:
  * Compatibility support improvement: Support for mawk in creation
    of pstoedit.ph header file.
* Tue Sep  7 2021 Stanislav Brabec <sbrabec@suse.com>
- Update to version 3.77:
  * Added experimental support for filled objects in DXF output
    using the HATCH element of DXF.
  * Fixed a problem when running pstoedit with output to standard
    output instead of a file.
  * Adapted to new versioning scheme of GhostScript.
  * Additional backend for pcb-rnd.
  * Some additional options in WEMF driver.
  * Better handling of bounding box in EMF output.
  * Better handling of metric option in fig driver.
* Thu Sep 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.75:
  * Fix a compile problem under certain MacOS versions.
  * Various changes needed for interworking with newer versions of GhostScript.
  * Some code modernization based on feedback from VS-2019, Clang Powertools
    and PVS Studio.
  * Added support for dotted and dashed lines to the DXF backend.
  * Reduce redundancy in help documents.
  * Porting to Windows CE by Rohan Shetty.
  * Made pstoedit compatible with ghostscript 9.27.
  * Fix a bug occurring with large scale factors.
  * Include full documentation by default and provide an option to generate
    documentation locally which then fit best to the local installation.
  * Started to apply improvements proposed by clang-tidy.
  * Included a bunch of patches from Debian for easier maintenance of the
    package plus correction to some spelling issues. Thanks to Barak A.
    Pearlmutter.
  * added a -vl option to specify a verbosity level. Using the older -v enables
    level 1. For more use -vl 2.
  * included a patch contributed by OpenSuse folks fixing a problem in finding
    the plugins under certain conditions.
  * included a patch contributed by Martin Madsen related to checking non
    existing directories when looking for plugins.
  * added support for pdfwithshow and pdfawidthshow special operators when
    reading PDF files.
  * Scott Pakin updated the cfdg driver to support the current version of cfdg.
  * changes needed for newer versions of GhostScript.
  * some code cleanup. pstoedit passed all Coverity checks.
- remove pstoedit-imagemagick7.patch pstoedit-pkglibdir.patch (obsolete)
- rediff reproducible.patch
* Wed Sep 20 2017 pgajdos@suse.com
- build against ImageMagick 7
  + pstoedit-imagemagick7.patch
* Fri Mar  4 2016 bwiedemann@suse.com
- Add reproducible.patch to make build-compare work
* Fri Mar 13 2015 sbrabec@suse.cz
- Fix plugin search algorithm (pstoedit-pkglibdir.patch).
- Drop patches:
  * pstoedit-parallel.patch: It was apparently autotools fault.
  * pstoedit-3.50-plugin-close.patch: Triggering bnc#680125 is
    fixed since 12.2.
  * pstoedit-3.60-libdl.patch: Patch is correct, but not needed.
* Thu Mar 12 2015 p.drouand@gmail.com
- Update to version 3.70
  * some code improvement
  * removed the -DBUGGYGPP compile flag since now g++ can compile the
    code without it. The former work-arounds are still there but will
    be removed later.
  * enabled more warnings when compiling with g++ and fixed some
    resulting warnings.
  * changed the autoconf part to better support the inclusion of
    libzip for the pptx driver.
  * included a lot of documentation corrections
  * using non case sensitive comparison when determining the target
    format from the file suffix.
  * using more STL classes instead of older private replacements
    (string and vector). In this context also some hard coded limits
    were removed.
  * fixed an assertion violation when using -ssp and a closepath occurred.
  * added the dump of the font name for the DXF format.
    prototype of a "simulate fill" option for emulating filling by stroking.
    This is based on fillpoly.c from the hp2xx project. This is still kind
    of experimental.
- Update pstoedit-3.62-parallel.patch > pstoedit-parallel.patch
* Fri May 30 2014 tchvatal@suse.com
- Version bump to 3.62:
  * new backend generating PowerPoint pptx files
  * improved handling of composite fonts
  * fixed a bug in detecting rectangles.
  * improved bounding box tracing in case of text (but it is still not perfect).
  * changed the creation of filenames when using the -split option.
  * fixed a bug in passing generic libplot arguments to the libplot drivers.
  * improved support for 64-bit systems related the integration of pstoedit to gsview.
  * include a version info resource in pstoedit's windows exe and DLLs.
  * include a work-around for a Hurd specific problem with dlclose.
- New patches to fix build behaviour:
  * pstoedit-3.60-libdl.patch
  * pstoedit-3.62-parallel.patch
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Wed Nov  7 2012 sbrabec@suse.cz
- Update to version 3.61:
  * fixed a bug in handling of -page option.
  * improved support for 64-bit systems related to different
    version of ghostscript
  * added some features for supporting the LaOS project
    (Laser Open Source Cutting, http://www.laoslaser.org/)
* Fri May 25 2012 sbrabec@suse.cz
- Build against libEMF on all platforms.
* Tue Apr 10 2012 ro@suse.de
- fix buildrequires, ImageMagick-Magick++-devel
  is now libMagick++-devel
* Sun Jan 22 2012 tabraham@novell.com
- removed patches deprecated by this release
  - pstoedit-3.50-libadd.patch
  - pstoedit-cxxflags.patch
  - pstoedit-no_builddir_in_la_file.patch
- refreshed pstoedit-3.50-plugin-close.patch
- update to 3.60
  + added option (-minlinewidth) for adjusting very thing (e.g.
    zero-width) lines to a minimal width.
  + added option (-pslanguagelevel) for easy switching the
    language level to be used by GhostScript during interpretation
    of the PostScript/PDF file
  + new driver for the "Context Free" drawing tool
    (http://www.contextfreeart.org/ ) contributed by Scott Pakin
  + fixed the windows binary version - some drivers were missing
  + fixed some problems in handling composite fonts (FontType=0)
  + windows 32 bit binary can call 64 bit ghostscript as exe
    (i.e. not via DLL interface)
  + support for 64 bit windows and Office 2010
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Aug 10 2010 sbrabec@suse.cz
- Fixed parallel build.
- Build with correct CFLAGS.
* Mon Aug  9 2010 sbrabec@suse.cz
- Don't dlclose() in destructors (bnc#622977, Redhat#507035).
* Sat Feb 13 2010 dimstar@opensuse.org
- Reformatting of the package meta description.
* Wed Aug 12 2009 sbrabec@suse.cz
- Updated to version 3.50:
  * Improvements to the PCB and mpost drivers.
  * Improvements of the font substitution mechanism.
  * New drivers: gcode (.ngc), .vtk (e.g. ParaView).
  * Added Cairo output driver (outputs Cairo C code).
  * Fixed clipping and image support for the Asymptote backend.
  * Fixed line width problem with the xfig format.
  * Code adaptations for newer libraries and compilers.
  * Other enhancements and bugfixes.
* Fri Jun  5 2009 coolo@novell.com
- fix compilation with gcc 4.4
- rediff to avoid fuzz
* Thu Jan 15 2009 sbrabec@suse.cz
- Enhanced features of PCB output.
- Build with gd.
- Changed BuildRequires: plotutils -> plotutils-devel.
- Spec file cleanup.
* Wed Sep 10 2008 jsmeix@suse.de
- fixes-for-GCC43.patch applies fixes for GCC 4.3,
  see http://en.opensuse.org/GCC_4.3_Transition
- Update to version 3.45;
  * Fixed a bug in the fig backend related to dotted lines.
  * Better support for pagesize handling.
  * Better handling of fonts using 0 encoded characters
  * Fixed endless loop issue of GhostScript
    (see Novell/Suse Bugzilla bnc#414188).
* Fri Aug 22 2008 meissner@suse.de
- build with optflags, some cleanups
* Wed Jul 18 2007 ke@suse.de
- Add plotutils to BuildRequires to fix SVG support; reported by
  Christian Morales Vega [# 292023].
* Tue Feb 27 2007 dmueller@suse.de
- reduce BuildRequires
* Tue Aug  1 2006 ke@suse.de
- Remove joe from BuildRequires; reported by Christoph Thiel.
* Mon Mar 13 2006 ke@suse.de
- Update to version 3.44:
  * Use secure versions of several functions where possible.
  * Add a driver for the OpenOffice metafile format.
- Add pkgconfig to BuildRequires.
- Drop obsolete codecleanup patch.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 24 2005 ke@suse.de
- Update to version 3.42.
* Thu Sep  1 2005 pth@suse.de
- Update to version 3.41 which fixes the SIGSEGV (#113777)
- Fix LDFLAGS so that buildroot vanishes from .la file
- Fix CXXFLAGS.
- Handle man pages via Makefile instead of spec file.
* Tue Aug  2 2005 ke@suse.de
- Update to version 3.40.
- Adjust Requires.
* Tue Sep 14 2004 ro@suse.de
- added ImageMagick-Magick++-devel to neededforbuild
* Mon Jun 28 2004 ro@suse.de
- added libtiff to neededforbuild
* Tue Feb  3 2004 ro@suse.de
- libEMF does not compile with "-pedantic", remove
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Mon Jul 28 2003 meissner@suse.de
- Added libexif to nfb.
* Wed Jul  2 2003 ke@suse.de
- Update to version 3.33.
* Wed Jul  2 2003 ro@suse.de
- remove buildroot traces from installed files
* Thu Jun 12 2003 kukuk@suse.de
- Add lib directory to filelist
* Fri Jan  3 2003 ke@suse.de
- Add liblcms-devel to neededforbuild.
- Fix license tag.
- Fix description in PDB.
* Thu Nov 21 2002 sbrabec@suse.cz
- Turned on EMF/WMF support (needs libEMF).
* Mon Nov 11 2002 sbrabec@suse.cz
- Updated to version 3.32.
- Added dependencies for new features.
- Splitted to pstoedit and pstoedit-devel.
- Install root workaround for of plugins (LDFLAGS and sed script).
* Tue Apr  9 2002 ro@suse.de
- don't apply gcc-3 patch if running gcc-2.95
* Sun Apr  7 2002 schwab@suse.de
- Fix for gcc3.
* Fri Mar 22 2002 ke@suse.de
- Call suse_update_config and regenerate configure to make it build on
  architecture != x86.
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan  3 2002 ke@suse.de
- Update to version 3.31:
  - Fixes and enhancements to EMF/WMF, HPGL, CGM, DXF, and SVG.
  - Data files are in /usr/share/pstoedit .
- Drop DESTDIR patch (it's in the original 3.31 release).
* Thu Nov  8 2001 ke@suse.de
- Make cgmdraw a package on its own.
- Cleanup spec file: enable %%clean; enable test suite; remove unused
  variables.
* Thu Nov  8 2001 ke@suse.de
- Update to version 3.30 (proposed by Wolfgang Glunz and Uwe Drechsel,
  [# 12218]):
  - Support more backends; lots of enhancements and cleanups.
  - Compatible with plotutils 2.4.1.
* Fri Jul 20 2001 kukuk@suse.de
- changed neededforbuild <gs_fonts> to <ghostscript-fonts-std>
- changed neededforbuild <gs_lib> to <ghostscript-library>
- changed neededforbuild <gs_x11> to <ghostscript-x11>
* Fri Nov 17 2000 ke@suse.de
- update to version 3.21.
- cleanup spec file; use macros, add group tag (#4246).
* Fri Jun  2 2000 ke@suse.de
- update to version 3.18.
- start to cleanup the spec file.
- use DESTDIR.
* Mon Sep 20 1999 ro@suse.de
- added requires ghostscript_any
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Apr  5 1999 bs@suse.de
- fixed date strings in .changes.
* Tue Feb 23 1999 ke@suse.de
- update: version 3.03.
* Fri Nov 13 1998 bs@suse.de
- fixed spec file (double entries)
* Thu Nov 12 1998 bs@suse.de
- fixed spec file for new rpm.
* Mon Dec  8 1997 ke@suse.de
- rename the cd package: now its called cgmdraw.
- list /usr/include/cd.h and /usr/lib/libcd.a in %%files.
* Wed Dec  3 1997 ke@suse.de
- initial package: pstoedit 2.60 and cd 1.3.
